@@ -22,3 +22,6 @@ class ForceReply(ReplyMarkup):
         if self.selective:
             json_data['selective'] = self.selective
         return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
